Module utoipauto_core::string_utils
source · Functions
- Return the list of all the functions with the #[utoipa] attribute and the list of all the structs with the #[derive(ToSchema)] attribute and the list of all the structs with the #[derive(ToResponse)] attribute
- Extract the file paths from the attributes Support the old syntax (MODULE_TREE_PATH => MODULE_SRC_PATH) ; (MODULE_TREE_PATH => MODULE_SRC_PATH) ; and the new syntax MODULE_SRC_PATH, MODULE_SRC_PATH